using Reduce

# explicitly calculate l1 integral over reference triangle with first order
# lagrange discretization
function l1triangle()
    int3 = :(abs(u0 * (1-x1-x2) + u1 * x1 + u2 * x2))
    int2 = Reduce.Algebra.int(int3, :x2, 0, :(1 - x1))
    int1 = Reduce.Algebra.int(int2, :x1, 0, 1)
    return int1
end

function l1interval()
    integrand = :(abs(u0 * (1-x) + u1 * x))
    return Reduce.Algebra.int(integrand, :x, 0, 1)
end

function norm_grad()
    function ref_int(f)
        inty_f = Algebra.int(f, :y, 0, :(1 - x))
        return Algebra.int(inty_f, :x, 0, 1)
    end

    # \|f\|
    f = :(a * x + b * y + c * (1 - x - y))
    n2_f = ref_int(:(($f)^2))

    # \|grad f\|
    dx_f = Algebra.df(f, :x)
    dy_f = Algebra.df(f, :y)
    n2_gradf = ref_int(:(($dx_f)^2 + ($dy_f)^2))

    return :($n2_gradf / $n2_f)
end
